===========================
Changes in version 2017.1.0
===========================

FIAT 2017.1.0 was released on 2017-05-09.

Summary of changes
==================

- Extended the discontinuous trace element ``HDivTrace`` to support tensor
  product reference cells. Tabulating the trace defined on a tensor product
  cell relies on the argument ``entity`` to specify a facet of the cell. The
  backwards compatibility case ``entity=None`` does not support tensor product
  tabulation as a result. Tabulating the trace of triangles or tetrahedron
  remains unaffected and works as usual with or without an entity argument.
